@@ -109,6 +109,7 @@ class DetDatabase:
         end_delivery_date: datetime = None,
         columns: list = None,
         process_data: bool = True,
+        timezone_aware_dates: bool = False,
     ) -> pd.DataFrame:
         """
         Loads entsoe day-ahead spot prices from the database.
@@ -128,6 +129,8 @@ class DetDatabase:
             columns: Requested database table columns. Set columns=["*"] (i.e. as list) to get
                 all columns.
             process_data: Indicates if data should be processed convert to standardized format
+            timezone_aware_dates: If true, returns all dates as timezone-aware. Otherwise,
+                returns them as timezone-naive.
 
         Returns:
             Dataframe containing day-ahead spot prices
@@ -137,8 +140,6 @@ class DetDatabase:
                 compatible
             ValueError: Raises an error if the combination of trading dates and delivery dates
                 is not valid.
-            ValueError: Raises an error if match with input commodity name is not unique
-            ValueError: Raises an error if input commodity is not supported
             ValueError: Raises an error if no price data is found for user inputs
         """
         # Input validation
@@ -181,21 +182,13 @@ class DetDatabase:
         # Note: The local timezone is important because ENTSOE provides all prices in the UTC
         # timezone. We first convert the dates from UTC to the local timezone, and then filter
         # for the requested delivery period.
-        commodity_info = self.load_commodities(
-            columns=["Timezone", "EntsoeMapCode"], conditions=f"WHERE Name='{commodity_name}'"
+        commodity_info = self.get_commodity_info(
+            filter_column="Name",
+            filter_value=commodity_name,
+            info_columns=["Timezone", "EntsoeMapCode"],
         )
-        if commodity_info.shape[0] > 1:
-            raise ValueError(f"More than one match found with commodity '{commodity_name}'.")
-        elif commodity_info.shape[0] == 0:
-            supported_commodities = self.load_commodities(columns=["Name"])
-            supported_commodities_str = ", ".join(f"'{x}'" for x in supported_commodities["Name"])
-            raise ValueError(
-                f"Commodity '{commodity_name}' is not supported. Supported commodities: "
-                f"{supported_commodities_str}."
-            )
-        else:
-            map_code = commodity_info.loc[0, "EntsoeMapCode"]
-            timezone = commodity_info.loc[0, "Timezone"]
+        map_code = commodity_info["EntsoeMapCode"]
+        timezone = commodity_info["Timezone"]
 
         # Convert start trading date to start delivery date
         if start_trading_date is not None:
@@ -239,11 +232,20 @@ class DetDatabase:
             by=["DateTime(UTC)"], axis=0, ascending=True, inplace=True, ignore_index=True
         )
 
+        # Convert date columns to timezone-aware dates
+        cols_date_utc = ["DateTime(UTC)", "UpdateTime(UTC)", "InsertionTimestamp"]
+        for c in cols_date_utc:
+            if c in df.columns:
+                df[c] = df[c].dt.tz_localize("UTC")
+
         # Add column with delivery date expressed in local timezone
-        datetime_column_name = f"DateTime({timezone})"
-        df[datetime_column_name] = df["DateTime(UTC)"].dt.tz_localize("UTC")
-        df[datetime_column_name] = df[datetime_column_name].dt.tz_convert(timezone)
-        df[datetime_column_name] = df[datetime_column_name].dt.tz_localize(None)
+        df[f"DateTime({timezone})"] = df["DateTime(UTC)"].dt.tz_convert(timezone)
+
+        if not timezone_aware_dates:
+            cols_date_all = cols_date_utc + [f"DateTime({timezone})"]
+            for c in cols_date_all:
+                if c in df.columns:
+                    df[c] = df[c].dt.tz_localize(None)
 
         # Process raw data and convert it to standardized format
         if process_data:
@@ -266,6 +268,8 @@ class DetDatabase:
         Returns:
             Processed dataframe containing day-ahead spot prices
         """
+        df_in.reset_index(drop=True, inplace=True)
+
         # Initialize output dataframe
         df_out = pd.DataFrame()
 
@@ -277,7 +281,7 @@ class DetDatabase:
         df_out["TradingDate"] = trading_date
 
         # Set delivery start date
-        df_out["DeliveryStart"] = df_in[f"DateTime({timezone})"].values
+        df_out["DeliveryStart"] = df_in[f"DateTime({timezone})"]
 
         # Set delivery end date
         delivery_end = [d + relativedelta(hours=1) for d in df_in[f"DateTime({timezone})"]]
@@ -300,6 +304,7 @@ class DetDatabase:
         end_delivery_date: datetime = None,
         columns: list = None,
         process_data: bool = True,
+        timezone_aware_dates: bool = False,
     ) -> pd.DataFrame:
         """
         Loads entsoe imbalance prices from the database.
@@ -319,6 +324,8 @@ class DetDatabase:
             columns: Requested database table columns. Set columns=["*"] (i.e. as list) to get
                 all columns.
             process_data: Indicates if data should be processed convert to standardized format
+            timezone_aware_dates: If true, returns all dates as timezone-aware. Otherwise,
+                returns them as timezone-naive.
 
         Returns:
             Dataframe containing imbalance prices
@@ -328,8 +335,6 @@ class DetDatabase:
                 compatible
             ValueError: Raises an error if the combination of trading dates and delivery dates
                 is not valid.
-            ValueError: Raises an error if match with input commodity name is not unique
-            ValueError: Raises an error if input commodity is not supported
             ValueError: Raises an error if no price data is found for user inputs
         """
         # Input validation
@@ -378,21 +383,13 @@ class DetDatabase:
         # Note: The local timezone is important because ENTSOE provides all prices in the UTC
         # timezone. We first convert the dates from UTC to the local timezone, and then filter
         # for the requested delivery period.
-        commodity_info = self.load_commodities(
-            columns=["Timezone", "EntsoeMapCode"], conditions=f"WHERE Name='{commodity_name}'"
+        commodity_info = self.get_commodity_info(
+            filter_column="Name",
+            filter_value=commodity_name,
+            info_columns=["Timezone", "EntsoeMapCode"],
         )
-        if commodity_info.shape[0] > 1:
-            raise ValueError(f"More than one match found with commodity '{commodity_name}'.")
-        elif commodity_info.shape[0] == 0:
-            supported_commodities = self.load_commodities(columns=["Name"])
-            supported_commodities_str = ", ".join(f"'{x}'" for x in supported_commodities["Name"])
-            raise ValueError(
-                f"Commodity '{commodity_name}' is not supported. Supported commodities: "
-                f"{supported_commodities_str}."
-            )
-        else:
-            map_code = commodity_info.loc[0, "EntsoeMapCode"]
-            timezone = commodity_info.loc[0, "Timezone"]
+        map_code = commodity_info["EntsoeMapCode"]
+        timezone = commodity_info["Timezone"]
 
         # Convert start trading date to start delivery date
         if start_trading_date is not None:
@@ -405,8 +402,7 @@ class DetDatabase:
 
         # Convert end trading date to end delivery date
         if end_trading_date is not None:
-            end_trading_date = pd.Timestamp(end_trading_date).floor("D")
-            end_delivery_date = end_trading_date + relativedelta(days=1)
+            end_trading_date = pd.Timestamp(end_trading_date).floor("D") + relativedelta(days=1)
 
         # Convert end date to UTC and string
         end_delivery_date = end_delivery_date.replace(tzinfo=ZoneInfo(timezone))
@@ -435,11 +431,20 @@ class DetDatabase:
             by=["DateTime(UTC)"], axis=0, ascending=True, inplace=True, ignore_index=True
         )
 
+        # Convert date columns to timezone-aware dates
+        cols_date_utc = ["DateTime(UTC)", "UpdateTime(UTC)", "InsertionTimestamp"]
+        for c in cols_date_utc:
+            if c in df.columns:
+                df[c] = df[c].dt.tz_localize("UTC")
+
         # Add column with delivery date expressed in local timezone
-        datetime_column_name = f"DateTime({timezone})"
-        df[datetime_column_name] = df["DateTime(UTC)"].dt.tz_localize("UTC")
-        df[datetime_column_name] = df[datetime_column_name].dt.tz_convert(timezone)
-        df[datetime_column_name] = df[datetime_column_name].dt.tz_localize(None)
+        df[f"DateTime({timezone})"] = df["DateTime(UTC)"].dt.tz_convert(timezone)
+
+        if not timezone_aware_dates:
+            cols_date_all = cols_date_utc + [f"DateTime({timezone})"]
+            for c in cols_date_all:
+                if c in df.columns:
+                    df[c] = df[c].dt.tz_localize(None)
 
         # Process raw data and convert it to standardized format
         if process_data:
@@ -462,6 +467,8 @@ class DetDatabase:
         Returns:
             Processed dataframe containing imbalance prices
         """
+        df_in.reset_index(drop=True, inplace=True)
+
         # Initialize output dataframe
         df_out = pd.DataFrame()
 
@@ -469,10 +476,10 @@ class DetDatabase:
         df_out["CommodityName"] = [commodity_name] * df_in.shape[0]
 
         # Set trading date
-        df_out["TradingDate"] = df_in[f"DateTime({timezone})"].dt.floor("D").values
+        df_out["TradingDate"] = df_in[f"DateTime({timezone})"].dt.floor("D")
 
         # Set delivery start date
-        df_out["DeliveryStart"] = df_in[f"DateTime({timezone})"].values
+        df_out["DeliveryStart"] = df_in[f"DateTime({timezone})"]
 
         # Set delivery end date
         delivery_end = [d + relativedelta(minutes=15) for d in df_in[f"DateTime({timezone})"]]
@@ -495,6 +502,7 @@ class DetDatabase:
         tenors: list,
         delivery_type: str,
         columns: list = None,
+        timezone_aware_dates: bool = False,
     ) -> pd.DataFrame:
         """
         Loads futures end-of-day settlement prices from the database, over a user-defined range
@@ -508,6 +516,8 @@ class DetDatabase:
             delivery_type: Delivery type ("Base", "Peak", "Offpeak")
             columns: Requested database table columns. Set columns=["*"] (i.e. as list) to get
                 all columns.
+            timezone_aware_dates: If true, returns all dates as timezone-aware. Otherwise,
+                returns them as timezone-naive.
 
         Returns:
             Dataframe containing futures end-of-day settlement prices
@@ -561,9 +571,24 @@ class DetDatabase:
         )
 
         # Convert dates from datetime.date to pd.Timestamp
-        df["TradingDate"] = pd.DatetimeIndex(df["TradingDate"])
-        df["DeliveryStart"] = pd.DatetimeIndex(df["DeliveryStart"])
-        df["DeliveryEnd"] = pd.DatetimeIndex(df["DeliveryEnd"])
+        cols_date = ["TradingDate", "DeliveryStart", "DeliveryEnd"]
+        for c in cols_date:
+            if c in df.columns:
+                df[c] = pd.DatetimeIndex(df[c])
+
+        if timezone_aware_dates:
+            # Get local timezone
+            commodity_info = self.get_commodity_info(
+                filter_column="Name", filter_value=commodity_name, info_columns=["Timezone"]
+            )
+            timezone = commodity_info["Timezone"]
+
+            # Convert timezone-naive to timezone-aware dates
+            df["InsertionTimestamp"] = df["InsertionTimestamp"].dt.tz_localize("UTC")
+            cols_local_tz = ["TradingDate", "DeliveryStart", "DeliveryEnd"]
+            for c in cols_local_tz:
+                if c in df.columns:
+                    df[c] = df[c].dt.tz_localize(timezone)
 
         return df
 
@@ -640,25 +665,22 @@ class DetDatabase:
         return commodity_info
 
     def load_account_positions(
-        self,
-        start_trading_date: datetime,
-        end_trading_date: datetime,
-        columns: list = None,
+        self, start_trading_date: datetime, end_trading_date: datetime, columns: list = None
     ) -> pd.DataFrame:
         """
         Loads account positions from the database, over a user-defined range of trading dates.
 
         Args:
-            start_trading_date: Start trading date
-            end_trading_date: End trading date
+            start_trading_date: Start trading date.
+            end_trading_date: End trading date.
             columns: Requested database table columns. Set columns=["*"] (i.e. as list) to get
                 all columns.
 
         Returns:
-            Dataframe containing quarterly account positions
+            Dataframe containing account positions.
 
         Raises:
-            ValueError: Raises an error if no account position data is found for user inputs
+            ValueError: Raises an error if no position data is found for user inputs.
         """
         # Set default column values
         if columns is None:
@@ -671,6 +693,7 @@ class DetDatabase:
             columns_str = f"[{'], ['.join(columns)}]"
 
         # Convert dates from datetime to string
+        end_trading_date = pd.Timestamp(end_trading_date).floor("D") + relativedelta(days=1)
         start_trading_date_str = start_trading_date.strftime("%Y-%m-%d")
         end_trading_date_str = end_trading_date.strftime("%Y-%m-%d")
 
@@ -678,8 +701,8 @@ class DetDatabase:
         table = DetDatabaseDefinitions.DEFINITIONS["table_name_account_position"]
         query = (
             f"SELECT {columns_str} FROM {table} "
-            f"WHERE CAST ([InsertionTimestamp] AS DATE) IN ('{start_trading_date_str}', "
-            f"'{end_trading_date_str}') "
+            f"WHERE InsertionTimestamp>='{start_trading_date_str}' "
+            f"AND InsertionTimestamp<'{end_trading_date_str}'"
         )
 
         # Query db
@@ -687,12 +710,133 @@ class DetDatabase:
         df = self.query_db(query)
         self.close_connection()
 
+        # Assert data
         if df.empty:
             raise ValueError("No account position data found for user-defined inputs.")
 
+        # Sort data and convert dates from datetime.date to pd.Timestamp
+        if "InsertionTimestamp" in df.columns:
+            df.sort_values(
+                by=["InsertionTimestamp"],
+                axis=0,
+                ascending=True,
+                inplace=True,
+                ignore_index=True,
+            )
+            df["InsertionTimestamp"] = pd.DatetimeIndex(df["InsertionTimestamp"])
+
+        return df
+
+    def load_instruments(self, identifiers: list, columns: list = None) -> pd.DataFrame:
+        """
+        Loads instrument data based on identifier (of account positions) from the database.
+
+        Args:
+            identifiers: Instrument identifiers (of account positions).
+            columns: Requested database table columns. Set columns=["*"] (i.e. as list) to get
+                all columns.
+
+        Returns:
+            Dataframe containing instrument data.
+
+        Raises:
+            ValueError: Raises an error if no instrument data is found for user inputs.
+        """
+        # Set default column values
+        if columns is None:
+            columns = ["*"]
+
+        # Convert columns from list to string
+        if len(columns) == 1:
+            columns_str = str(columns[0])
+        else:
+            columns_str = f"[{'], ['.join(columns)}]"
+
+        # Convert tenors from list to string
+        identifiers_str = ", ".join(f"'{i}'" for i in identifiers)
+
+        # Create query
+        table = DetDatabaseDefinitions.DEFINITIONS["table_name_instruments"]
+        query = f"SELECT {columns_str} FROM {table} WHERE [id] IN ({identifiers_str})"
+
+        # Query db
+        self.open_connection()
+        df = self.query_db(query)
+        self.close_connection()
+
+        # Assert data
+        if df.empty:
+            raise ValueError("No instrument data found for user-defined inputs.")
+
+        return df
+
+    def load_eex_eod_prices(
+        self,
+        product_code: str,
+        start_trading_date: datetime,
+        end_trading_date: datetime,
+        columns: list = None,
+    ) -> pd.DataFrame:
+        """
+        Loads futures end-of-day EEX prices from the database, over a user-defined range of trading
+        dates.
+
+        Args:
+            product_code: Product code format indicating commodity, tenor and delivery type as
+                defined in the EEX.EODPrice DET database. Assumed product code format do not
+                include other product code format (i.e. DEBW and DEBWE do not co-exist)
+            start_trading_date: Start trading date.
+            end_trading_date: End trading date.
+            columns: Requested database table columns. Set columns=["*"] (i.e. as list) to get
+                all columns.
+
+        Returns:
+            Dataframe containing EEX futures end-of-day prices.
+
+        Raises:
+            ValueError: Raises an error if no price data is found for user inputs.
+        """
+        # Set default column values
+        if columns is None:
+            columns = ["*"]
+        else:
+            # Assert required columns
+            columns = list(
+                set(columns)
+                | {"TradingDate", "Product", "Delivery Start", "Delivery End", "Settlement Price"}
+            )
+
+        # Convert columns from list to string
+        if len(columns) == 1:
+            columns_str = str(columns[0])
+        else:
+            columns_str = f"[{'], ['.join(columns)}]"
+
+        # Convert dates from datetime to string
+        start_trading_date_str = start_trading_date.strftime("%Y-%m-%d")
+        end_trading_date_str = end_trading_date.strftime("%Y-%m-%d")
+
+        # Create query
+        table = DetDatabaseDefinitions.DEFINITIONS["table_name_eex_eod_price"]
+        query = (
+            f"SELECT {columns_str} FROM {table} "
+            f"WHERE Product LIKE '{product_code}' "
+            f"AND TradingDate>='{start_trading_date_str}' "
+            f"AND TradingDate<='{end_trading_date_str}'"
+        )
+
+        # Query db
+        self.open_connection()
+        df = self.query_db(query)
+        self.close_connection()
+
+        # Assert data
+        if df.empty:
+            raise ValueError("No price data found for user-defined inputs.")
+
         # Sort data
         df.sort_values(
-            by=["InsertionTimestamp"],
+            by=["TradingDate", "Delivery Start", "Delivery End"],
             axis=0,
             ascending=True,
             inplace=True,
@@ -700,10 +844,311 @@ class DetDatabase:
         )
 
         # Convert dates from datetime.date to pd.Timestamp
-        df["InsertionTimestamp"] = pd.DatetimeIndex(df["InsertionTimestamp"])
+        cols_date = ["TradingDate", "Delivery Start", "Delivery End"]
+        for c in cols_date:
+            if c in df.columns:
+                df[c] = pd.DatetimeIndex(df[c])
+
+        # Drop duplicates
+        df = df.drop_duplicates()
 
         return df
 
+    def load_forecast_customer_volume(
+        self,
+        profile: str,
+        forecast_date: datetime,
+        start_delivery_date: datetime,
+        end_delivery_date: datetime,
+        local_timezone: str,
+        timezone_aware_dates: bool = False,
+        columns: list = None,
+    ) -> pd.DataFrame:
+        """
+        Loads customer volume forecasts from the database.
+
+        Args:
+            profile: Customer/profile name.
+                Note on the 'Portfolio' and 'Portfolioweekend' profiles:
+                - Profile names 'Portfolio' and 'Portfolioweekend' refer to the same set of
+                    connection points.
+                - In the database, the profile name is set to 'Portfolio' when the forecast date
+                    is between Monday and Friday.
+                - In the database, the profile name is set to 'Portfolioweekend' when the forecast
+                    date is Saturday or Sunday.
+                - When calling this method, the input argument 'profile' can be set to
+                    'PortfolioAll' to automatically let the method switch between 'Portfolio' and
+                    'Portfolioweekend', based on the used-input forecast date.
+            forecast_date: Date on which customer volume forecast is generated.
+            start_delivery_date: First delivery date included.
+            end_delivery_date: Last delivery date included.
+            local_timezone: Local timezone (needed to account for DST switches).
+            timezone_aware_dates: If true, returns all dates as timezone-aware. Otherwise, returns
+                them as timezone-naive.
+            columns: Requested database table columns. Set columns=["*"] (i.e. as list) to get all
+                columns.
+
+        Returns:
+            Dataframe containing customer volume forecasts.
+
+        Raises:
+            ValueError: Raises an error if no volume forecast data is found for user inputs.
+        """
+        # Convert profile if set to "PortfolioAll"
+        if profile == "PortfolioAll":
+            if forecast_date.weekday() > 4:
+                profile = "Portfolioweekend"
+            else:
+                profile = "Portfolio"
+
+        # Convert start delivery date from local timezone to UTC and string
+        start_delivery_date = start_delivery_date.replace(tzinfo=ZoneInfo(local_timezone))
+        start_delivery_date = start_delivery_date.astimezone(ZoneInfo("UTC"))
+        start_date_str = start_delivery_date.strftime("%Y-%m-%d %H:%M:%S")
+
+        # Convert end delivery date form local timezone to UTC and string
+        end_delivery_date = pd.Timestamp(end_delivery_date).floor("D") + relativedelta(days=1)
+        end_delivery_date = end_delivery_date.replace(tzinfo=ZoneInfo(local_timezone))
+        end_delivery_date = end_delivery_date.astimezone(ZoneInfo("UTC"))
+        end_date_str = end_delivery_date.strftime("%Y-%m-%d %H:%M:%S")
+
+        # Set default column values
+        if columns is None:
+            columns = ["*"]
+
+        # Convert columns from list to string
+        if len(columns) == 1:
+            columns_str = str(columns[0])
+        else:
+            columns_str = f"[{'], ['.join(columns)}]"
+
+        # Convert dates from datetime to string
+        forecast_date_str = forecast_date.strftime("%Y-%m-%d")
+
+        # Create query
+        table = DetDatabaseDefinitions.DEFINITIONS["table_name_forecast_customer_volume"]
+        query = (
+            f"SELECT {columns_str} FROM {table} "
+            f"WHERE Profile='{profile}' "
+            f"AND ForecastDate='{forecast_date_str}' "
+            f"AND Datetime>='{start_date_str}' "
+            f"AND Datetime<'{end_date_str}'"
+        )
+
+        # Query db
+        self.open_connection()
+        df = self.query_db(query)
+        self.close_connection()
+
+        # Assert data
+        if df.empty:
+            raise ValueError("No volume forecast data found for user-defined inputs.")
+
+        # Sort data
+        sort_cols = ["Profile", "ForecastDate", "Datetime"]
+        sort_cols = [c for c in sort_cols if c in df.columns]
+        if len(sort_cols) > 0:
+            df.sort_values(
+                by=sort_cols,
+                axis=0,
+                ascending=True,
+                inplace=True,
+                ignore_index=True,
+            )
+
+        # Localize, convert and set timezone-(un)aware datetimes
+        cols_date = ["ForecastDate", "Datetime", "InsertionTimestamp"]
+        for c in cols_date:
+            if c in df.columns:
+                # Convert from datetime to pandas timestamp
+                df[c] = pd.DatetimeIndex(df[c])
+
+                # Convert to timezone-aware dates
+                if c == "ForecastDate":
+                    df[c] = df[c].dt.tz_localize(local_timezone)
+                else:
+                    df[c] = df[c].dt.tz_localize("UTC")
+                    df[c] = df[c].dt.tz_convert(local_timezone)
+
+                if not timezone_aware_dates:
+                    df[c] = df[c].dt.tz_localize(None)
+
+        # Rescale column values
+        df["kWh"] = df["kWh"] / 1000
+
+        # Rename columns
+        df = df.rename(columns={"kWh": "Volume(MWh)", "Datetime": "DeliveryStart"})
+
+        return df
+
+    def load_customer_day_ahead_auction_bids(
+        self,
+        client_id: str,
+        start_delivery_date: datetime,
+        end_delivery_date: datetime,
+        local_timezone: str,
+        timezone_aware_dates: bool = False,
+        columns: list = None,
+    ) -> pd.DataFrame:
+        """
+        Loads customer day-ahead auction bids (volumes and limit prices) from the database.
+
+        Args:
+            client_id: Client ID
+            start_delivery_date: First delivery date included
+            end_delivery_date: Last delivery date included
+            local_timezone: Local timezone (needed to account for DST switches)
+            timezone_aware_dates: If true, returns all dates as timezone-aware. Otherwise, returns
+                them as timezone-naive
+            columns: Requested database table columns. Set columns=["*"] (i.e. as list) to get all
+                columns
+
+        Returns:
+            Dataframe containing customer day-ahead auction bids
+
+        Raises:
+            ValueError: Raises an error if no data is found for user inputs
+        """
+        # Convert start delivery date from local timezone to UTC and string
+        start_delivery_date = start_delivery_date.replace(tzinfo=ZoneInfo(local_timezone))
+        start_delivery_date = start_delivery_date.astimezone(ZoneInfo("UTC"))
+        start_date_str = start_delivery_date.strftime("%Y-%m-%d %H:%M:%S")
+
+        # Convert end delivery date form local timezone to UTC and string
+        end_delivery_date = pd.Timestamp(end_delivery_date).floor("D") + relativedelta(days=1)
+        end_delivery_date = end_delivery_date.replace(tzinfo=ZoneInfo(local_timezone))
+        end_delivery_date = end_delivery_date.astimezone(ZoneInfo("UTC"))
+        end_date_str = end_delivery_date.strftime("%Y-%m-%d %H:%M:%S")
+
+        # Set default column values
+        if columns is None:
+            columns = ["*"]
+
+        # Convert columns from list to string
+        if len(columns) == 1:
+            columns_str = str(columns[0])
+        else:
+            columns_str = f"[{'], ['.join(columns)}]"
+
+        # Create query
+        table = DetDatabaseDefinitions.DEFINITIONS["table_name_customer_day_ahead_auction_bids"]
+        query = (
+            f"SELECT {columns_str} FROM {table} "
+            f"WHERE ClientId='{client_id}' "
+            f"AND DeliveryStart>='{start_date_str}' "
+            f"AND DeliveryStart<'{end_date_str}'"
+        )
+
+        # Query db
+        self.open_connection()
+        df = self.query_db(query)
+        self.close_connection()
+
+        # Assert data
+        if df.empty:
+            raise ValueError("No data found for user-defined inputs.")
+
+        # Sort data
+        sort_cols = ["ClientId", "InsertionTimestamp", "DeliveryStart"]
+        sort_cols = [c for c in sort_cols if c in df.columns]
+        if len(sort_cols) > 0:
+            df.sort_values(
+                by=sort_cols,
+                axis=0,
+                ascending=True,
+                inplace=True,
+                ignore_index=True,
+            )
+
+        # Localize, convert and set timezone-(un)aware datetimes
+        cols_date = ["DeliveryStart", "DeliveryEnd", "InsertionTimestamp"]
+        for c in cols_date:
+            if c in df.columns:
+                # Convert from datetime to pandas timestamp
+                df[c] = pd.DatetimeIndex(df[c])
+
+                # Convert to timezone-aware dates
+                if c == "InsertionTimestamp":
+                    df[c] = df[c].dt.tz_localize(local_timezone)
+                else:
+                    df[c] = df[c].dt.tz_localize("UTC")
+                    df[c] = df[c].dt.tz_convert(local_timezone)
+
+                if not timezone_aware_dates:
+                    df[c] = df[c].dt.tz_localize(None)
+
+        return df
+
+    def load_clients(self, columns: list = None, conditions: str = None) -> pd.DataFrame:
+        """
+        General method to load data from the database's client table.
+
+        Args:
+            columns: Requested database table columns. Set columns=["*"] (i.e. as list) to get
+                all columns.
+            conditions: Optional conditions to add to SQL query. E.g. "WHERE Type='Supplier'".
+
+        Returns:
+            Table data
+        """
+        # Set default column values
+        if columns is None:
+            columns = ["*"]
+
+        # Convert columns from list to string
+        if len(columns) == 1:
+            columns_str = str(columns[0])
+        else:
+            columns_str = f"[{'], ['.join(columns)}]"
+
+        # Create query
+        table = DetDatabaseDefinitions.DEFINITIONS["table_name_client"]
+        query = f"SELECT {columns_str} FROM {table} {conditions}"
+
+        # Query db
+        self.open_connection()
+        df = self.query_db(query)
+        self.close_connection()
+
+        return df
+
+    def get_client_info(self, filter_column: str, filter_value: str, info_columns: list) -> dict:
+        """
+        Finds information related to a specific, user-defined client.
+
+        Args:
+            filter_column: Column used to filter data for one specific client
+            filter_value: Value used to filter data for one specific client
+            info_columns: Columns containing the requested information
+
+        Returns:
+            A dictionary containing the requested information
+
+        Raises:
+            ValueError: Raises an error if match with input filter value is not unique
+            ValueError: Raises an error if the input filter value is not found
+        """
+        # Get client information for user-defined filtering criteria
+        condition = f"WHERE {filter_column}='{filter_value}'"
+        client_info = self.load_clients(columns=info_columns, conditions=condition)
+
+        # Validate response
+        if client_info.shape[0] > 1:
+            raise ValueError(f"More than one match found for {filter_column}={filter_value}.")
+
+        elif client_info.shape[0] == 0:
+            available_values = self.load_clients(columns=[filter_column])
+            available_values_str = ", ".join(f"'{x}'" for x in available_values[filter_column])
+            raise ValueError(
+                f"Value {filter_value} not found in column '{filter_column}'. Available values: "
+                f"{available_values_str}."
+            )
+
+        # Convert dataframe row to dict
+        client_info = client_info.loc[0, :].to_dict()
+
+        return client_info
+
 
 class DetDatabaseDefinitions:
     """A class containing some hard-coded definitions related to the DET database."""
@@ -714,4 +1159,9 @@ class DetDatabaseDefinitions:
         table_name_entsoe_imbalance_price="[ENTSOE].[ImbalancePrice]",
         table_name_futures_eod_settlement_price="[VW].[EODSettlementPrice]",
         table_name_account_position="[TT].[AccountPosition]",
+        table_name_instruments="[TT].[Instrument]",
+        table_name_eex_eod_price="[EEX].[EODPrice]",
+        table_name_forecast_customer_volume="[DISP].[ForecastGold]",
+        table_name_customer_day_ahead_auction_bids="[TRADE].[ClientBid]",
+        table_name_client="[META].[Client]",
     )
